IO
--

.. currentmodule:: dask_awkward

.. autosummary::

   from_awkward
   from_dask_array
   from_delayed
   from_json
   from_lists
   from_map
   to_dask_array
   to_delayed

.. autofunction:: from_awkward
.. autofunction:: from_dask_array
.. autofunction:: from_delayed
.. autofunction:: from_json
.. autofunction:: from_lists
.. autofunction:: from_map
.. autofunction:: to_dask_array
.. autofunction:: to_delayed
